# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Facade to find Dictionaries on Disk """
from lingpatlab.baseblock import BaseObject


class DictionaryFinder(BaseObject):
    """ Facade to find Dictionaries on Disk """

    def __init__(self):
        """
        Created:
            25-Aug-2022
            craigtrim@gmail.com
        """
        BaseObject.__init__(self, __name__)

    @staticmethod
    def hyphens() -> dict:
        from lingpatlab.tokenizer.dto import d_hyphens
        return d_hyphens

    @staticmethod
    def currency() -> dict:
        from lingpatlab.tokenizer.dto import d_currency
        return d_currency

    @staticmethod
    def squotes() -> dict:
        from lingpatlab.tokenizer.dto import squotes
        return squotes

    @staticmethod
    def dquotes() -> dict:
        from lingpatlab.tokenizer.dto import dquotes
        return dquotes

    @staticmethod
    def enclitics() -> dict:
        from lingpatlab.tokenizer.dto import d_enclictics
        return d_enclictics

    @staticmethod
    def abbreviations() -> dict:
        from lingpatlab.tokenizer.dto import d_abbreviations
        return d_abbreviations



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Add Punctuation Flag to Token """


from lingpatlab.baseblock import BaseObject


class TokenParserPunctuation(BaseObject):
    """ Add Punctuation Flag to Token """

    __punkt = [
        '!', '?', ':', '.', '"', '-', '(', ')'
    ]

    def __init__(self):
        """ Change Log

        Created:
            13-Oct-2021
            craigtrim@gmail.com
            *   refactored out of 'parse-input-tokens' in pursuit of
                https://github.com/grafflr/graffl-core/issues/41
        Updated:
            16-Sept-2022
            craigtrim@gmail.com
            *   rename component
                https://github.com/craigtrim/spacy-token-parser/issues/3
        """
        BaseObject.__init__(self, __name__)

    def process(self,
                tokens: list) -> list:
        """Add Punctuation Flag to tokens that are considered punctuation

        Args:
            tokens (list): list of tokens

        Returns:
            list: list of tokens
        """
        results = []

        for token in tokens:

            def ispunct(input_text: str) -> bool:
                return input_text in self.__punkt

            token['is_punct'] = ispunct(token['text'])
            results.append(token)

        return results



from .abbreviations_kb import d_abbreviations
from .currency_kb import d_currency
from .dquotes_kb import dquotes
from .enclictics import d_enclictics
from .hyphens_kb import d_hyphens
from .squotes_kb import squotes
from .stopwords_kb import stopwords




#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_d_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.146457'}

wordnet_terms_d = [
    'da',
    'dab',
    'daba',
    'dabble',
    'dabbled',
    'dabbler',
    'dabbles',
    'dabbling',
    'dabchick',
    'daboecia',
    'dacca',
    'dace',
    'dacelo',
    'dacha',
    'dachau',
    'dachshund',
    'dachsie',
    'dacite',
    'dacitic',
    'dacninae',
    'dacoit',
    'dacoits',
    'dacoity',
    'dacron',
    'dacrycarpus',
    'dacrydium',
    'dacrymyces',
    'dacrymycetaceae',
    'dacryocyst',
    'dacryocystitis',
    'dacryon',
    'dactyl',
    'dactylic',
    'dactylis',
    'dactyloctenium',
    'dactylomegaly',
    'dactylopiidae',
    'dactylopius',
    'dactylopteridae',
    'dactylopterus',
    'dactylorhiza',
    'dactyloscopidae',
    'dad',
    'dada',
    'dadaism',
    'daddy',
    'dado',
    'daedal',
    'daedalus',
    'daemon',
    'daffo',
    'daffodil',
    'dafla',
    'daft',
    'daftness',
    'dag',
    'dagame',
    'dagan',
    'dagda',
    'dagestani',
    'dagga',
    'dagger',
    'daggerboard',
    'dago',
    'dagon',
    'daguerre',
    'daguerreotype',
    'dah',
    'dahl',
    'dahlia',
    'dahna',
    'dahomey',
    'daikon',
    'dail',
    'daily',
    'daimler',
    'daimon',
    'daintiness',
    'dainty',
    'daiquiri',
    'dairen',
    'dairies',
    'dairy',
    'dairying',
    'dairymaid',
    'dairyman',
    'dais',
    'daishiki',
    'daisies',
    'daisy',
    'daisybush',
    'daisylike',
    'dak',
    'dakar',
    'dakoit',
    'dakoity',
    'dakota',
    'dakotas',
    'dal',
    'dalai',
    'dalasi',
    'dalbergia',
    'dale',
    'dalea',
    'dales',
    'dalesman',
    'daleth',
    'dali',
    'dalian',
    'dallas',
    'dalliance',
    'dallier',
    'dallisgrass',
    'dally',
    'dalmane',
    'dalmatia',
    'dalmatian',
    'dalo',
    'dalton',
    'daltonism',
    'dam',
    'dama',
    'damage',
    'damaged',
    'damages',
    'damaging',
    'damaliscus',
    'damar',
    'damascene',
    'damascened',
    'damascus',
    'damask',
    'dame',
    'damgalnunna',
    'daminozide',
    'damkina',
    'dammar',
    'dammed',
    'damming',
    'dammini',
    'damn',
    'damnable',
    'damnation',
    'damnatory',
    'damned',
    'damning',
    'damocles',
    'damoiselle',
    'damon',
    'damosel',
    'damourite',
    'damozel',
    'damp',
    'damped',
    'dampen',
    'dampener',
    'dampening',
    'dampens',
    'damper',
    'dampers',
    'damping',
    'dampish',
    'dampness',
    'dams',
    'damsel',
    'damselfish',
    'damselfishes',
    'damselflies',
    'damselfly',
    'damson',
    'dana',
    'danaea',
    'danaid',
    'danaidae',
    'danau',
    'danaus',
    'dance',
    'danceable',
    'danced',
    'dancer',
    'dancers',
    'dances',
    'dancing',
    'dandelion',
    'dandelions',
    'dander',
    'dandified',
    'dandify',
    'dandle',
    'dandled',
    'dandruff',
    'dandy',
    'dandyish',
    'dandyism',
    'dane',
    'danes',
    'danewort',
    'dangaleat',
    'danger',
    'dangerous',
    'dangerously',
    'dangerousness',
    'dangers',
    'dangla',
    'dangle',
    'dangleberry',
    'dangled',
    'dangling',
    'daniel',
    'danish',
    'dank',
    'dankness',
    'danmark',
    'danseur',
    'danseuse',
    'dante',
    'dantean',
    'dantesque',
    'danton',
    'danu',
    'danube',
    'danzig',
    'dao',
    'daoism',
    'daphne',
    'daphnia',
    'dapper',
    'dapperness',
    'dapple',
    'dappled',
    'dapsang',
    'dapsone',
    'daraf',
    'dard',
    'dardan',
    'dardanelles',
    'dardanian',
    'dardanus',
    'dardic',
    'dare',
    'dared',
    'daredevil',
    'daredevilry',
    'daredeviltry',
    'dares',
    'darfur',
    'dari',
    'daricon',
    'darien',
    'daring',
    'darius',
    'darjeeling',
    'dark',
    'darken',
    'darkened',
    'darkening',
    'darkens',
    'darker',
    'darkest',
    'darkish',
    'darkling',
    'darkly',
    'darkness',
    'darkroom',
    'darling',
    'darlingtonia',
    'darmera',
    'darmstadtium',
    'darn',
    'darned',
    'darnel',
    'darner',
    'darning',
    'darpa',
    'darrow',
    'darsana',
    'dart',
    'dartboard',
    'darted',
    'darter',
    'darting',
    'dartmouth',
    'darts',
    'darvon',
    'darwin',
    'darwinian',
    'darwinism',
    'das',
    'dash',
    'dashboard',
    'dashed',
    'dasheen',
    'dashes',
    'dashiell',
    'dashiki',
    'dashing',
    'dassie',
    'dastard',
    'dastardliness',
    'dastardly',
    'dasyatidae',
    'dasyatis',
    'dasymeter',
    'dasypodidae',
    'dasyprocta',
    'dasyproctidae',
    'dasypus',
    'dasyure',
    'dasyurid',
    'dasyuridae',
    'dasyurus',
    'dat',
    'data',
    'database',
    'databases',
    'datable',
    'date',
    'dateable',
    'dated',
    'dateless',
    'dateline',
    'datemark',
    'dates',
    'dating',
    'dative',
    'datril',
    'datum',
    'datura',
    'daub',
    'daubentonia',
    'daubentoniidae',
    'dauber',
    'daubers',
    'daubing',
    'daucus',
    'daugavpils',
    'daughter',
    'daughterly',
    'daughters',
    'daumier',
    'daunt',
    'daunted',
    'daunting',
    'dauntless',
    'dauntlessness',
    'dauphin',
    'davallia',
    'davalliaceae',
    'davenport',
    'david',
    'daviesia',
    'davis',
    'davit',
    'davy',
    'davys',
    'daw',
    'dawah',
    'dawdle',
    'dawdler',
    'dawdling',
    'dawes',
    'dawn',
    'dawned',
    'dawning',
    'dawson',
    'day',
    'dayan',
    'daybed',
    'daybook',
    'dayboy',
    'daybreak',
    'daycare',
    'daydream',
    'daydreamer',
    'daydreaming',
    'daydreams',
    'dayflower',
    'dayfly',
    'daygirl',
    'daylight',
    'daylights',
    'daylily',
    'daylong',
    'daypro',
    'days',
    'dayspring',
    'daystar',
    'daytime',
    'dayton',
    'daze',
    'dazed',
    'dazzle',
    'dazzled',
    'dazzling',
    'dazzlingly',
    'db',
    'dba',
    'dbms',
    'dc',
    'dccp',
    'dci',
    'dd',
    'ddc',
    'ddi',
    'dds',
    'ddt',
    'de',
    'dea',
    'deaccession',
    'deaccessioned',
    'deacon',
    'deaconess',
    'deactivate',
    'deactivated',
    'deactivates',
    'deactivating',
    'deactivation',
    'dead',
    'deadbeat',
    'deadbolt',
    'deaden',
    'deadened',
    'deadening',
    'deadens',
    'deadeye',
    'deadhead',
    'deadheads',
    'deadlight',
    'deadline',
    'deadliness',
    'deadlock',
    'deadlocked',
    'deadly',
    'deadness',
    'deadpan',
    'deadwood',
    'deaerate',
    'deaf',
    'deafen',
    'deafened',
    'deafening',
    'deafness',
    'deal',
    'dealer',
    'dealers',
    'dealership',
    'dealfish',
    'dealignment',
    'dealing',
    'dealings',
    'deals',
    'dealt',
    'deaminase',
    'deaminate',
    'deamination',
    'deaminization',
    'deaminize',
    'dean',
    'deanery',
    'deans',
    'deanship',
    'dear',
    'dearest',
    'dearie',
    'dearly',
    'dearness',
    'dearth',
    'deary',
    'death',
    'deathbed',
    'deathblow',
    'deathless',
    'deathlike',
    'deathly',
    'deathrate',
    'deaths',
    'deathtrap',
    'deathwatch',
    'deb',
    'debacle',
    'debar',
    'debark',
    'debarkation',
    'debarment',
    'debarred',
    'debase',
    'debased',
    'debasement',
    'debaser',
    'debases',
    'debasing',
    'debatable',
    'debate',
    'debated',
    'debater',
    'debates',
    'debating',
    'debauch',
    'debauched',
    'debauchee',
    'debaucher',
    'debauchery',
    'debenture',
    'debile',
    'debilitate',
    'debilitated',
    'debilitating',
    'debilitation',
    'debilitative',
    'debility',
    'debit',
    'debited',
    'debitor',
    'debits',
    'debonair',
    'debonaire',
    'debone',
    'deboned',
    'debonnaire',
    'debouch',
    'debouched',
    'debridement',
    'debrief',
    'debriefing',
    'debris',
    'debs',
    'debt',
    'debtor',
    'debts',
    'debug',
    'debugged',
    'debugger',
    'debugging',
    'debunk',
    'debunked',
    'debunking',
    'debussy',
    'debut',
    'debutante',
    'debuts',
    'dec',
    'decade',
    'decadence',
    'decadency',
    'decadent',
    'decades',
    'decadron',
    'decaf',
    'decaffeinate',
    'decagon',
    'decagram',
    'decahedron',
    'decal',
    'decalcification',
    'decalcify',
    'decalcomania',
    'decalescence',
    'decalescent',
    'decaliter',
    'decalitre',
    'decalogue',
    'decameter',
    'decametre',
    'decamp',
    'decamped',
    'decampment',
    'decant',
    'decantation',
    'decanted',
    'decanter',
    'decapitate',
    'decapitated',
    'decapitating',
    'decapitation',
    'decapod',
    'decapoda',
    'decapterus',
    'decarbonate',
    'decarbonise',
    'decarbonize',
    'decarboxylase',
    'decarboxylate',
    'decarboxylation',
    'decarburise',
    'decarburize',
    'decasyllabic',
    'decasyllable',
    'decathlon',
    'decatur',
    'decay',
    'decayable',
    'decayed',
    'decaying',
    'decays',
    'decease',
    'deceased',
    'decedent',
    'deceit',
    'deceitful',
    'deceitfulness',
    'deceive',
    'deceived',
    'deceiver',
    'deceives',
    'deceiving',
    'decelerate',
    'deceleration',
    'december',
    'decency',
    'decennary',
    'decennium',
    'decent',
    'decentalisation',
    'decentralisation',
    'decentralise',
    'decentralised',
    'decentralization',
    'decentralize',
    'decentralized',
    'deception',
    'deceptive',
    'deceptively',
    'deceptiveness',
    'decerebrate',
    'decertify',
    'dechlorinate',
    'decibel',
    'decibels',
    'decide',
    'decided',
    'decidedly',
    'decides',
    'deciding',
    'decidua',
    'deciduous',
    'decigram',
    'decile',
    'deciliter',
    'decilitre',
    'decimal',
    'decimalisation',
    'decimalise',
    'decimalization',
    'decimalize',
    'decimalized',
    'decimate',
    'decimation',
    'decimeter',
    'decimetre',
    'decipher',
    'decipherable',
    'deciphered',
    'decipherer',
    'deciphering',
    'decipherment',
    'decision',
    'decisions',
    'decisive',
    'decisively',
    'decisiveness',
    'decius',
    'deck',
    'decked',
    'decker',
    'deckhand',
    'deckle',
    'deckled',
    'decks',
    'declaim',
    'declaimed',
    'declaiming',
    'declamation',
    'declamatory',
    'declarable',
    'declaration',
    'declarative',
    'declaratory',
    'declare',
    'declared',
    'declarer',
    'declares',
    'declaring',
    'declassification',
    'declassified',
    'declassify',
    'declaw',
    'declension',
    'declination',
    'decline',
    'declined',
    'declines',
    'declining',
    'declinometer',
    'declivitous',
    'declivity',
    'declomycin',
    'declutch',
    'deco',
    'decoagulant',
    'decoct',
    'decoction',
    'decode',
    'decoder',
    'decodes',
    'decoding',
    'decoke',
    'decollate',
    'decolletage',
    'decollete',
    'decolonisation',
    'decolonise',
    'decolonization',
    'decolonize',
    'decolonized',
    'decolor',
    'decolorise',
    'decolorize',
    'decolorized',
    'decolour',
    'decolourise',
    'decolourize',
    'decommission',
    'decommissioned',
    'decomposable',
    'decompose',
    'decomposed',
    'decomposes',
    'decomposing',
    'decomposition',
    'decompositional',
    'decompound',
    'decompress',
    'decompressing',
    'decompression',
    'deconcentrate',
    'decongestant',
    'deconsecrate',
    'deconsecrated',
    'deconstruct',
    'deconstructing',
    'deconstruction',
    'deconstructionism',
    'deconstructionist',
    'deconstructivism',
    'decontaminate',
    'decontaminated',
    'decontamination',
    'decontrol',
    'decor',
    'decorate',
    'decorated',
    'decorates',
    'decorating',
    'decoration',
    'decorations',
    'decorative',
    'decoratively',
    'decorativeness',
    'decorator',
    'decorous',
    'decorousness',
    'decorticate',
    'decortication',
    'decorum',
    'decoupage',
    'decouple',
    'decoy',
    'decrease',
    'decreased',
    'decreases',
    'decreasing',
    'decree',
    'decreed',
    'decrees',
    'decrement',
    'decrepit',
    'decrepitate',
    'decrepitation',
    'decrepitude',
    'decrescendo',
    'decrescendoes',
    'decriminalisation',
    'decriminalise',
    'decriminalization',
    'decriminalize',
    'decry',
    'decrypt',
    'decryption',
    'decubitus',
    'decumaria',
    'decumary',
    'decumbent',
    'decurved',
    'decussate',
    'decussates',
    'decussation',
    'ded',
    'dedicate',
    'dedicated',
    'dedicating',
    'dedication',
    'dedifferentiate',
    'dedifferentiated',
    'dedifferentiation',
    'deduce',
    'deduced',
    'deducible',
    'deduct',
    'deducted',
    'deductible',
    'deducting',
    'deduction',
    'deductions',
    'deductive',
    'deed',
    'deedbox',
    'deeds',
    'deem',
    'deemed',
    'deep',
    'deepen',
    'deepened',
    'deepening',
    'deeper',
    'deepest',
    'deepfreeze',
    'deeply',
    'deepness',
    'deer',
    'deerberry',
    'deere',
    'deerhound',
    'deerskin',
    'deerstalker',
    'deerstalking',
    'deface',
    'defaced',
    'defacement',
    'defaces',
    'defacing',
    'defalcate',
    'defalcation',
    'defalcator',
    'defamation',
    'defamatory',
    'defame',
    'defamed',
    'defamer',
    'defaming',
    'defang',
    'defat',
    'default',
    'defaulter',
    'defaults',
    'defeasible',
    'defeat',
    'defeated',
    'defeating',
    'defeatism',
    'defeatist',
    'defeats',
    'defecate',
    'defecates',
    'defecating',
    'defecation',
    'defecator',
    'defect',
    'defected',
    'defection',
    'defective',
    'defectiveness',
    'defector',
    'defects',
    'defeminise',
    'defeminize',
    'defence',
    'defenceless',
    'defencelessness',
    'defend',
    'defendable',
    'defendant',
    'defendants',
    'defended',
    'defender',
    'defenders',
    'defending',
    'defends',
    'defenestrate',
    'defenestrated',
    'defenestration',
    'defense',
    'defenseless',
    'defenselessness',
    'defenses',
    'defensibility',
    'defensible',
    'defensive',
    'defensiveness',
    'defer',
    'deference',
    'deferens',
    'deferent',
    'deferential',
    'defering',
    'deferment',
    'deferral',
    'deferred',
    'defervesce',
    'defervescence',
    'defervescent',
    'defiance',
    'defiant',
    'defiantly',
    'defibrillate',
    'defibrillated',
    'defibrillation',
    'defibrillator',
    'defibrinate',
    'deficiencies',
    'deficiency',
    'deficient',
    'deficit',
    'deficits',
    'defied',
    'defies',
    'defilade',
    'defile',
    'defiled',
    'defilement',
    'defiler',
    'defiling',
    'definable',
    'define',
    'defined',
    'defines',
    'defining',
    'definite',
    'definitely',
    'definiteness',
    'definition',
    'definitions',
    'definitive',
    'deflagrate',
    'deflagration',
    'deflate',
    'deflated',
    'deflation',
    'deflationary',
    'deflator',
    'deflect',
    'deflected',
    'deflecting',
    'deflection',
    'deflective',
    'deflector',
    'deflects',
    'deflexion',
    'defloration',
    'deflower',
    'deflowered',
    'defoe',
    'defog',
    'defoliant',
    'defoliate',
    'defoliated',
    'defoliation',
    'defoliator',
    'deforest',
    'deforestation',
    'deforested',
    'deform',
    'deformation',
    'deformational',
    'deformed',
    'deforming',
    'deformities',
    'deformity',
    'defraud',
    'defrauded',
    'defrauder',
    'defray',
    'defrayal',
    'defrayment',
    'defrays',
    'defrock',
    'defrost',
    'defroster',
    'deft',
    'deftly',
    'deftness',
    'defunct',
    'defunctness',
    'defuse',
    'defusing',
    'defy',
    'defying',
    'degage',
    'degas',
    'degauss',
    'degaussed',
    'degaussing',
    'degeneracy',
    'degenerate',
    'degenerated',
    'degenerates',
    'degeneration',
    'degenerative',
    'deglaze',
    'deglutition',
    'deglycerolise',
    'deglycerolize',
    'degradation',
    'degrade',
    'degraded',
    'degrader',
    'degrading',
    'degrease',
    'degree',
    'degrees',
    'degressive',
    'degust',
    'degustation',
    'dehisce',
    'dehiscence',
    'dehiscent',
    'dehiscing',
    'dehorn',
    'dehumanisation',
    'dehumanise',
    'dehumanised',
    'dehumanization',
    'dehumanize',
    'dehumanized',
    'dehumanizing',
    'dehumidifier',
    'dehumidifies',
    'dehumidify',
    'dehydrate',
    'dehydrated',
    'dehydrating',
    'dehydration',
    'dehydrogenate',
    'dehydrogenated',
    'dehydroretinol',
    'deice',
    'deicer',
    'deictic',
    'deific',
    'deification',
    'deified',
    'deifies',
    'deify',
    'deign',
    'deimos',
    'deinocheirus',
    'deinonychus',
    'deionize',
    'deipnosophist',
    'deism',
    'deist',
    'deistic',
    'deities',
    'deity',
    'deixis',
    'deja',
    'deject',
    'dejected',
    'dejectedness',
    'dejection',
    'dejeuner',
    'dekagram',
    'dekaliter',
    'dekalitre',
    'dekameter',
    'dekametre',
    'dekker',
    'dekko',
    'del',
    'delacroix',
    'delairea',
    'deland',
    'delavirdine',
    'delaware',
    'delawarean',
    'delawarian',
    'delay',
    'delayed',
    'delayer',
    'delaying',
    'delays',
    'delbruck',
    'delectability',
    'delectable',
    'delectation',
    'delegacy',
    'delegate',
    'delegated',
    'delegates',
    'delegating',
    'delegation',
    'delete',
    'deleted',
    'deleterious',
    'deleting',
    'deletion',
    'deletions',
    'delf',
    'delft',
    'delhi',
    'deli',
    'deliberate',
    'deliberately',
    'deliberateness',
    'deliberation',
    'deliberations',
    'deliberative',
    'delibes',
    'delible',
    'delicacy',
    'delicate',
    'delicately',
    'delicatessen',
    'delichon',
    'delicious',
    'deliciously',
    'deliciousness',
    'delight',
    'delighted',
    'delightful',
    'delighting',
    'delights',
    'delilah',
    'delimit',
    'delimitate',
    'delimitation',
    'delimited',
    'delineate',
    'delineated',
    'delineation',
    'delineative',
    'delinquency',
    'delinquent',
    'deliquesce',
    'deliquescent',
    'deliquesces',
    'deliquium',
    'delirious',
    'delirium',
    'delist',
    'delius',
    'deliver',
    'deliverable',
    'deliverables',
    'deliverance',
    'delivered',
    'deliverer',
    'deliveries',
    'delivering',
    'delivers',
    'delivery',
    'deliveryman',
    'dell',
    'delocalize',
    'delonix',
    'delorme',
    'delouse',
    'deloused',
    'delphi',
    'delphian',
    'delphic',
    'delphinapterus',
    'delphinidae',
    'delphinium',
    'delphinus',
    'delta',
    'deltasone',
    'deltoid',
    'delude',
    'deluge',
    'deluges',
    'delusion',
    'delusional',
    'delusions',
    'delusive',
    'delusory',
    'deluxe',
    'delve',
    'delving',
    'demagnetisation',
    'demagnetise',
    'demagnetization',
    'demagnetize',
    'demagnetized',
    'demagog',
    'demagogic',
    'demagogical',
    'demagogue',
    'demagoguery',
    'demagogy',
    'demand',
    'demanded',
    'demander',
    'demanding',
    'demands',
    'demantoid',
    'demarcate',
    'demarcated',
    'demarcation',
    'demarche',
    'demasculinise',
    'demasculinize',
    'dematerialise',
    'dematerialize',
    'dematerialized',
    'dematerializing',
    'dematiaceae',
    'demavend',
    'demean',
    'demeaning',
    'demeanor',
    'demeanour',
    'demented',
    'dementedness',
    'dementia',
    'demerara',
    'demerit',
    'demerits',
    'demerol',
    'demesne',
    'demeter',
    'demetrius',
    'demiglace',
    'demigod',
    'demijohn',
    'demilitarise',
    'demilitarize',
    'demilitarized',
    'demille',
    'demimondaine',
    'demimonde',
    'demineralisation',
    'demineralise',
    'demineralization',
    'demineralize',
    'demise',
    'demisemiquaver',
    'demist',
    'demister',
    'demitasse',
    'demiurge',
    'demo',
    'demob',
    'demobilisation',
    'demobilise',
    'demobilization',
    'demobilize',
    'democracy',
    'democrat',
    'democratic',
    'democratically',
    'democratisation',
    'democratise',
    'democratization',
    'democratize',
    'democrats',
    'democritus',
    'demode',
    'demodulate',
    'demodulated',
    'demodulates',
    'demodulation',
    'demodulator',
    'demogorgon',
    'demographer',
    'demographic',
    'demographist',
    'demography',
    'demoiselle',
    'demolish',
    'demolished',
    'demolishes',
    'demolishing',
    'demolition',
    'demon',
    'demonetisation',
    'demonetise',
    'demonetization',
    'demonetize',
    'demoniac',
    'demoniacal',
    'demonic',
    'demonisation',
    'demonise',
    'demonism',
    'demonization',
    'demonize',
    'demonized',
    'demonolatry',
    'demons',
    'demonstrability',
    'demonstrable',
    'demonstrably',
    'demonstrate',
    'demonstrated',
    'demonstrates',
    'demonstrating',
    'demonstration',
    'demonstrations',
    'demonstrative',
    'demonstrativeness',
    'demonstrator',
    'demonstrators',
    'demoralisation',
    'demoralise',
    'demoralised',
    'demoralising',
    'demoralization',
    'demoralize',
    'demoralized',
    'demoralizes',
    'demoralizing',
    'demos',
    'demosthenes',
    'demosthenic',
    'demote',
    'demoted',
    'demotic',
    'demotion',
    'dempsey',
    'demulcent',
    'demulen',
    'demulsify',
    'demur',
    'demure',
    'demureness',
    'demurrage',
    'demurral',
    'demurred',
    'demurrer',
    'demyelinate',
    'demyelinated',
    'demyelination',
    'demystify',
    'demythologisation',
    'demythologise',
    'demythologised',
    'demythologization',
    'demythologize',
    'demythologized',
    'den',
    'denali',
    'denary',
    'denationalisation',
    'denationalise',
    'denationalization',
    'denationalize',
    'denaturalise',
    'denaturalize',
    'denaturant',
    'denature',
    'denatured',
    'denaturing',
    'denaturised',
    'denaturized',
    'denazification',
    'denazified',
    'denazify',
    'dendranthema',
    'dendraspis',
    'dendriform',
    'dendrite',
    'dendrites',
    'dendritic',
    'dendroaspis',
    'dendrobium',
    'dendrocalamus',
    'dendrocolaptes',
    'dendrocolaptidae',
    'dendroctonus',
    'dendroica',
    'dendroid',
    'dendroidal',
    'dendrolagus',
    'dendrology',
    'dendromecon',
    'deneb',
    'denebola',
    'dengue',
    'deniable',
    'denial',
    'denials',
    'denied',
    'denier',
    'denies',
    'denigrate',
    'denigrating',
    'denigration',
    'denigrative',
    'denigratory',
    'denim',
    'denis',
    'denisonia',
    'denitrify',
    'denizen',
    'denmark',
    'dennett',
    'dennstaedtia',
    'dennstaedtiaceae',
    'denominate',
    'denomination',
    'denominational',
    'denominationalism',
    'denominations',
    'denominator',
    'denominators',
    'denotation',
    'denotative',
    'denotatum',
    'denote',
    'denoted',
    'denotes',
    'denoting',
    'denotive',
    'denouement',
    'denounce',
    'denounced',
    'denouncement',
    'denouncing',
    'dens',
    'dense',
    'densely',
    'denseness',
    'denser',
    'densification',
    'densimeter',
    'densities',
    'densitometer',
    'densitometry',
    'density',
    'dent',
    'dental',
    'dentaria',
    'dentate',
    'dented',
    'denticle',
    'denticulate',
    'dentifrice',
    'dentin',
    'dentine',
    'denting',
    'dentist',
    'dentistry',
    'dentists',
    'dentition',
    'denture',
    'denturist',
    'denudate',
    'denudation',
    'denude',
    'denuded',
    'denumerable',
    'denunciation',
    'denunciative',
    'denunciatory',
    'denver',
    'deny',
    'denying',
    'deodar',
    'deodorant',
    'deodorise',
    'deodorize',
    'deodourant',
    'deodourise',
    'deossification',
    'deoxidise',
    'deoxidize',
    'deoxidizing',
    'deoxyadenosine',
    'deoxycytidine',
    'deoxyephedrine',
    'deoxygenate',
    'deoxyguanosine',
    'deoxyribose',
    'deoxythymidine',
    'depardieu',
    'deparia',
    'depart',
    'departed',
    'departer',
    'departing',
    'department',
    'departmental',
    'departments',
    'departs',
    'departure',
    'departures',
    'depend',
    'dependability',
    'dependable',
    'dependableness',
    'dependably',
    'dependance',
    'dependant',
    'depended',
    'dependence',
    'dependency',
    'dependent',
    'dependents',
    'depending',
    'depends',
    'depersonalisation',
    'depersonalise',
    'depersonalization',
    'depersonalize',
    'depict',
    'depicted',
    'depicting',
    'depiction',
    'depictions',
    'depictive',
    'depicts',
    'depigmentation',
    'depilate',
    'depilation',
    'depilator',
    'depilatory',
    'depilous',
    'deplane',
    'depletable',
    'deplete',
    'depleted',
    'depletes',
    'depletion',
    'deplorable',
    'deplore',
    'deplored',
    'deploy',
    'deployed',
    'deployment',
    'deploys',
    'deplumate',
    'deplume',
    'depokene',
    'depolarisation',
    'depolarise',
    'depolarization',
    'depolarize',
    'depone',
    'deponent',
    'depopulate',
    'depopulated',
    'depopulation',
    'deport',
    'deportation',
    'deported',
    'deportee',
    'deportment',
    'depose',
    'deposed',
    'deposer',
    'deposing',
    'deposit',
    'depositary',
    'deposited',
    'depositing',
    'deposition',
    'depositions',
    'depositor',
    'depositories',
    'depositors',
    'depository',
    'deposits',
    'depot',
    'depots',
    'depravation',
    'deprave',
    'depraved',
    'depravity',
    'deprecate',
    'deprecating',
    'deprecation',
    'deprecative',
    'deprecatory',
    'depreciate',
    'depreciated',
    'depreciating',
    'depreciation',
    'depreciative',
    'depreciator',
    'depreciatory',
    'depredation',
    'depredations',
    'depress',
    'depressant',
    'depressed',
    'depresses',
    'depressing',
    'depressingly',
    'depression',
    'depressions',
    'depressive',
    'depressor',
    'depressurise',
    'depressurize',
    'deprivation',
    'deprive',
    'deprived',
    'deprives',
    'depriving',
    'depth',
    'depths',
    'deputation',
    'depute',
    'deputise',
    'deputize',
    'deputized',
    'deputy',
    'deracinate',
    'deracination',
    'derail',
    'derailed',
    'derailment',
    'derain',
    'derange',
    'deranged',
    'derangement',
    'derate',
    'derby',
    'derecognise',
    'derecognize',
    'derecognized',
    'deregulate',
    'deregulating',
    'deregulation',
    'derelict',
    'dereliction',
    'derelictions',
    'derelicts',
    'derequisition',
    'derestrict',
    'deride',
    'derided',
    'deriding',
    'derision',
    'derisive',
    'derisively',
    'derisory',
    'derivable',
    'derivation',
    'derivational',
    'derivations',
    'derivative',
    'derivatives',
    'derive',
    'derived',
    'derives',
    'deriving',
    'derma',
    'dermabrasion',
    'dermacentor',
    'dermal',
    'dermaptera',
    'dermatitis',
    'dermatobia',
    'dermatoglyphic',
    'dermatoglyphics',
    'dermatologic',
    'dermatological',
    'dermatologist',
    'dermatology',
    'dermatome',
    'dermatomycosis',
    'dermatomyositis',
    'dermatophytosis',
    'dermatosclerosis',
    'dermatosis',
    'dermestidae',
    'dermic',
    'dermis',
    'dermochelyidae',
    'dermochelys',
    'dermoptera',
    'derogate',
    'derogation',
    'derogative',
    'derogatory',
    'derrick',
    'derrida',
    'derriere',
    'derringer',
    'derris',
    'derv',
    'dervish',
    'dervishes',
    'derwinski',
    'des',
    'desacralize',
    'desalinate',
    'desalination',
    'desalinisation',
    'desalinise',
    'desalinization',
    'desalinize',
    'desalt',
    'desalted',
    'descale',
    'descant',
    'descartes',
    'descend',
    'descendant',
    'descendants',
    'descended',
    'descendent',
    'descendents',
    'descender',
    'descending',
    'descends',
    'descensus',
    'descent',
    'describable',
    'describe',
    'described',
    'describes',
    'describing',
    'description',
    'descriptions',
    'descriptive',
    'descriptivism',
    'descriptor',
    'descry',
    'descurainia',
    'desdemona',
    'desecrate',
    'desecrated',
    'desecration',
    'desegrated',
    'desegregate',
    'desegregation',
    'desensitisation',
    'desensitise',
    'desensitising',
    'desensitization',
    'desensitize',
    'desensitized',
    'desensitizing',
    'desert',
    'deserted',
    'deserter',
    'desertification',
    'deserting',
    'desertion',
    'deserts',
    'deserve',
    'deserved',
    'deserves',
    'deserving',
    'deservingness',
    'desex',
    'desexualise',
    'desexualize',
    'deshabille',
    'desiccant',
    'desiccate',
    'desiccated',
    'desiccation',
    'desiderata',
    'desideratum',
    'design',
    'designate',
    'designated',
    'designates',
    'designating',
    'designation',
    'designative',
    'designatum',
    'designed',
    'designer',
    'designers',
    'designing',
    'designs',
    'desipramine',
    'desirability',
    'desirable',
    'desirableness',
    'desire',
    'desired',
    'desires',
    'desiring',
    'desirous',
    'desist',
    'desk',
    'deskbound',
    'deskman',
    'desktop',
    'desmanthus',
    'desmid',
    'desmidiaceae',
    'desmidium',
    'desmids',
    'desmodium',
    'desmodontidae',
    'desmodus',
    'desmograthus',
    'desolate',
    'desolation',
    'desorb',
    'desorption',
    'despair',
    'despairing',
    'despatch',
    'desperado',
    'desperate',
    'desperately',
    'desperation',
    'despicability',
    'despicable',
    'despicableness',
    'despicably',
    'despisal',
    'despise',
    'despised',
    'despises',
    'despising',
    'despite',
    'despiteful',
    'despoil',
    'despoilation',
    'despoiled',
    'despoiler',
    'despoiling',
    'despoilment',
    'despoils',
    'despoina',
    'despoliation',
    'despond',
    'desponded',
    'despondence',
    'despondency',
    'despondent',
    'despot',
    'despotic',
    'despotical',
    'despotism',
    'desquamate',
    'desquamation',
    'dessert',
    'desserts',
    'dessertspoon',
    'dessertspoonful',
    'dessiatine',
    'destabilisation',
    'destabilise',
    'destabilization',
    'destabilize',
    'destabilized',
    'destain',
    'destalinisation',
    'destalinise',
    'destalinization',
    'destalinize',
    'destalinized',
    'destination',
    'destinations',
    'destine',
    'destined',
    'destiny',
    'destitute',
    'destitution',
    'destress',
    'destroy',
    'destroyable',
    'destroyed',
    'destroyer',
    'destroyers',
    'destroying',
    'destroys',
    'destruct',
    'destructibility',
    'destructible',
    'destruction',
    'destructive',
    'destructively',
    'destructiveness',
    'desuetude',
    'desulfurize',
    'desulphurize',
    'desultory',
    'desynchronisation',
    'desynchronise',
    'desynchronization',
    'desynchronize',
    'desynchronizing',
    'desyrel',
    'detach',
    'detachable',
    'detached',
    'detaches',
    'detachment',
    'detail',
    'detailed',
    'detailing',
    'details',
    'detain',
    'detained',
    'detainee',
    'detainment',
    'detains',
    'detect',
    'detectable',
    'detected',
    'detecting',
    'detection',
    'detective',
    'detectives',
    'detector',
    'detectors',
    'detects',
    'detent',
    'detente',
    'detention',
    'deter',
    'deterge',
    'detergence',
    'detergency',
    'detergent',
    'detergents',
    'deteriorate',
    'deteriorates',
    'deteriorating',
    'deterioration',
    'determent',
    'determinable',
    'determinant',
    'determinants',
    'determinate',
    'determinateness',
    'determination',
    'determinative',
    'determine',
    'determined',
    'determiner',
    'determines',
    'determining',
    'determinism',
    'determinist',
    'deterministic',
    'deterred',
    'deterrence',
    'deterrent',
    'deterring',
    'deters',
    'detersive',
    'detest',
    'detestable',
    'detestation',
    'detested',
    'detests',
    'dethaw',
    'dethrone',
    'dethroned',
    'dethronement',
    'detick',
    'detonate',
    'detonated',
    'detonates',
    'detonating',
    'detonation',
    'detonative',
    'detonator',
    'detonators',
    'detour',
    'detoured',
    'detox',
    'detoxicate',
    'detoxification',
    'detoxified',
    'detoxifies',
    'detoxify',
    'detract',
    'detracting',
    'detraction',
    'detractive',
    'detractor',
    'detracts',
    'detrain',
    'detransitivise',
    'detransitivize',
    'detribalisation',
    'detribalise',
    'detribalization',
    'detribalize',
    'detriment',
    'detrimental',
    'detrition',
    'detritus',
    'detroit',
    'detumescence',
    'detusk',
    'deuce',
    'deuced',
    'deuces',
    'deuteranopia',
    'deuteranopic',
    'deuterium',
    'deuteromycetes',
    'deuteromycota',
    'deuteromycotina',
    'deuteron',
    'deuteronomy',
    'deutsche',
    'deutschland',
    'deutschmark',
    'deutzia',
    'deux',
    'devaluate',
    'devaluation',
    'devalue',
    'devalued',
    'devalues',
    'devanagari',
    'devastate',
    'devastated',
    'devastating',
    'devastation',
    'devein',
    'develop',
    'developed',
    'developer',
    'developers',
    'developing',
    'development',
    'developmental',
    'developmentally',
    'developments',
    'develops',
    'devi',
    'deviance',
    'deviant',
    'deviate',
    'deviated',
    'deviates',
    'deviating',
    'deviation',
    'deviationism',
    'deviationist',
    'deviations',
    'device',
    'devices',
    'devil',
    'devilfish',
    'devilise',
    'devilish',
    'devilize',
    'devilized',
    'devilment',
    'devilry',
    'devils',
    'deviltry',
    'devilwood',
    'devious',
    'deviousness',
    'devisal',
    'devise',
    'devised',
    'devisee',
    'deviser',
    'devises',
    'devising',
    'devisor',
    'devitalisation',
    'devitalise',
    'devitalization',
    'devitalize',
    'devitalized',
    'devitrify',
    'devoice',
    'devoid',
    'devoir',
    'devolution',
    'devolve',
    'devolved',
    'devolvement',
    'devon',
    'devonian',
    'devonshire',
    'devote',
    'devoted',
    'devotedness',
    'devotee',
    'devotees',
    'devotes',
    'devoting',
    'devotion',
    'devotional',
    'devotions',
    'devour',
    'devoured',
    'devourer',
    'devouring',
    'devout',
    'devoutness',
    'devries',
    'dew',
    'dewar',
    'dewberries',
    'dewberry',
    'dewdrop',
    'dewey',
    'deweyan',
    'dewlap',
    'dewy',
    'dexamethasone',
    'dexedrine',
    'dexone',
    'dexter',
    'dexterity',
    'dexterous',
    'dextral',
    'dextrality',
    'dextrin',
    'dextrocardia',
    'dextroglucose',
    'dextrorotary',
    'dextrorotation',
    'dextrorotatory',
    'dextrorsal',
    'dextrorse',
    'dextrose',
    'dextrous',
    'dflp',
    'dg',
    'dhahran',
    'dhak',
    'dhaka',
    'dhal',
    'dharma',
    'dhaulagiri',
    'dhava',
    'dhawa',
    'dhegiha',
    'dhodhekanisos',
    'dhole',
    'dhoti',
    'dhow',
    'dhu',
    'dia',
    'diabatic',
    'diabeta',
    'diabetes',
    'diabetic',
    'diabetics',
    'diabolatry',
    'diabolic',
    'diabolical',
    'diabolically',
    'diabolise',
    'diabolism',
    'diabolist',
    'diabolize',
    'diacalpa',
    'diacetylmorphine',
    'diachronic',
    'diachrony',
    'diacritic',
    'diacritical',
    'diacritics',
    'diadem',
    'diadophis',
    'diadromous',
    'diaeresis',
    'diaghilev',
    'diaglyph',
    'diagnosable',
    'diagnose',
    'diagnosed',
    'diagnoses',
    'diagnosing',
    'diagnosis',
    'diagnostic',
    'diagnostician',
    'diagnostics',
    'diagonal',
    'diagonalisation',
    'diagonalise',
    'diagonalizable',
    'diagonalization',
    'diagonalize',
    'diagonally',
    'diagram',
    'diagrammatic',
    'diagrammatical',
    'diagramming',
    'diagrams',
    'diakinesis',
    'dial',
    'dialect',
    'dialectal',
    'dialectic',
    'dialectical',
    'dialectician',
    'dialectics',
    'dialectology',
    'dialects',
    'dialed',
    'dialeurodes',
    'dialog',
    'dialogue',
    'dialogues',
    'dials',
    'dialyse',
    'dialysis',
    'dialyze',
    'dialyzer',
    'diam',
    'diamagnet',
    'diamagnetic',
    'diamagnetism',
    'diamant',
    'diamante',
    'diamantine',
    'diameter',
    'diametral',
    'diametric',
    'diametrical',
    'diametrically',
    'diamine',
    'diamond',
    'diamondback',
    'diamonds',
    'diana',
    'dianoetic',
    'dianthus',
    'diapason',
    'diapedesis',
    'diapensia',
    'diapensiaceae',
    'diapensiales',
    'diaper',
    'diapers',
    'diaphanous',
    'diapheromera',
    'diaphone',
    'diaphoresis',
    'diaphoretic',
    'diaphragm',
    'diaphragmatic',
    'diaphyseal',
    'diaphysial',
    'diaphysis',
    'diapir',
    'diapsid',
    'diapsida',
    'diarchy',
    'diarist',
    'diarrhea',
    'diarrheal',
    'diarrheic',
    'diarrhetic',
    'diarrhoea',
    'diarrhoeal',
    'diarrhoeic',
    'diarrhoetic',
    'diarthrosis',
    'diary',
    'dias',
    'diaspididae',
    'diaspora',
    'diastasis',
    'diastema',
    'diastole',
    'diastolic',
    'diastrophism',
    'diathermy',
    'diathesis',
    'diatom',
    'diatomic',
    'diatomite',
    'diatomophyceae',
    'diatoms',
    'diatonic',
    'diatribe',
    'diaz',
    'diazepam',
    'diazo',
    'diazonium',
    'diazotize',
    'diazoxide',
    'dibasic',
    'dibber',
    'dibble',
    'dibbuk',
    'dibrach',
    'dibranch',
    'dibranchia',
    'dibranchiata',
    'dibranchiate',
    'dibs',
    'dibucaine',
    'dicamptodon',
    'dicamptodontid',
    'dicamptodontidae',
    'dicarboxylic',
    'dice',
    'diced',
    'dicentra',
    'dicer',
    'diceros',
    'dicey',
    'dichloride',
    'dichlorodiphenyltrichloroethane',
    'dichloromethane',
    'dichondra',
    'dichotomisation',
    'dichotomise',
    'dichotomization',
    'dichotomize',
    'dichotomous',
    'dichotomously',
    'dichotomy',
    'dichroism',
    'dichromacy',
    'dichromasy',
    'dichromat',
    'dichromate',
    'dichromates',
    'dichromatic',
    'dichromatism',
    'dichromatopsia',
    'dichromia',
    'dichromic',
    'dicing',
    'dick',
    'dickens',
    'dickensian',
    'dickenson',
    'dicker',
    'dickey',
    'dickeybird',
    'dickhead',
    'dickie',
    'dickinson',
    'dicksonia',
    'dicksoniaceae',
    'dicky',
    'dickybird',
    'diclinous',
    'dicloxacillin',
    'dicot',
    'dicotyledon',
    'dicotyledonae',
    'dicotyledones',
    'dicotyledonous',
    'dicoumarol',
    'dicranaceae',
    'dicranales',
    'dicranopteris',
    'dicranum',
    'dicrostonyx',
    'dictamnus',
    'dictaphone',
    'dictate',
    'dictated',
    'dictates',
    'dictation',
    'dictator',
    'dictatorial',
    'dictatorship',
    'diction',
    'dictionaries',
    'dictionary',
    'dictostylium',
    'dictum',
    'dictyophera',
    'dictyoptera',
    'dictyopteran',
    'dictyosome',
    'dicumarol',
    'dicynodont',
    'dicynodontia',
    'did',
    'didactic',
    'didactical',
    'didacticism',
    'didactics',
    'didanosine',
    'didder',
    'diddle',
    'diddley',
    'diddly',
    'diddlyshit',
    'diddlysquat',
    'didelphidae',
    'didelphis',
    'dideoxycytosine',
    'dideoxyinosine',
    'diderot',
    'didion',
    'dido',
    'didrikson',
    'die',
    'dieback',
    'diebacks',
    'died',
    'dieffenbachia',
    'diego',
    'diegueno',
    'diehard',
    'dielectric',
    'dielectrics',
    'dielectrolysis',
    'diemaker',
    'dien',
    'diencephalon',
    'dieresis',
    'diervilla',
    'dies',
    'diesel',
    'diesinker',
    'diesis',
    'diestock',
    'diestrous',
    'diestrual',
    'diestrum',
    'diestrus',
    'diet',
    'dietary',
    'dieter',
    'dietetic',
    'dietetical',
    'dietetics',
    'diethylamide',
    'diethylmalonylurea',
    'diethylstilbesterol',
    'diethylstilbestrol',
    'diethylstilboestrol',
    'dietician',
    'dieting',
    'dietitian',
    'dietrich',
    'diets',
    'differ',
    'difference',
    'differences',
    'different',
    'differentia',
    'differentiable',
    'differential',
    'differentially',
    'differentials',
    'differentiate',
    'differentiated',
    'differentiates',
    'differentiation',
    'differentiator',
    'differently',
    'differing',
    'differs',
    'difficult',
    'difficulties',
    'difficultness',
    'difficulty',
    'diffidence',
    'diffident',
    'difflugia',
    'diffract',
    'diffracted',
    'diffraction',
    'diffracts',
    'diffuse',
    'diffused',
    'diffusely',
    'diffuseness',
    'diffuser',
    'diffusers',
    'diffuses',
    'diffusing',
    'diffusion',
    'diffusive',
    'diffusor',
    'diflunisal',
    'dig',
    'digby',
    'digenesis',
    'digest',
    'digested',
    'digester',
    'digestibility',
    'digestible',
    'digestibleness',
    'digesting',
    'digestion',
    'digestive',
    'digests',
    'digger',
    'digging',
    'diggings',
    'dighted',
    'digit',
    'digital',
    'digitalin',
    'digitalis',
    'digitalisation',
    'digitalise',
    'digitalization',
    'digitalize',
    'digitally',
    'digitaria',
    'digitate',
    'digitately',
    'digitigrade',
    'digitisation',
    'digitise',
    'digitiser',
    'digitization',
    'digitize',
    'digitizer',
    'digitoxin',
    'digits',
    'dignified',
    'dignify',
    'dignifying',
    'dignitaries',
    'dignitary',
    'dignity',
    'digoxin',
    'digram',
    'digraph',
    'digress',
    'digresses',
    'digression',
    'digressive',
    'digs',
    'dihybrid',
    'dihydrostreptomycin',
    'dihydroxyphenylalanine',
    'dijon',
    'dika',
    'dike',
    'dikes',
    'dilantin',
    'dilapidate',
    'dilapidated',
    'dilapidation',
    'dilatation',
    'dilate',
    'dilated',
    'dilater',
    'dilates',
    'dilating',
    'dilation',
    'dilations',
    'dilator',
    'dilatoriness',
    'dilatory',
    'dilaudid',
    'dildo',
    'dilemma',
    'dilemmas',
    'dilettante',
    'dilettanteish',
    'dilettantish',
    'diligence',
    'diligent',
    'dill',
    'dillenia',
    'dilleniaceae',
    'dilleniid',
    'dilleniidae',
    'dillydallier',
    'dillydally',
    'diltiazem',
    'diluent',
    'dilutant',
    'dilute',
    'diluted',
    'diluting',
    'dilution',
    'diluvial',
    'diluvian',
    'dim',
    'dimaggio',
    'dimash',
    'dime',
    'dimenhydrinate',
    'dimension',
    'dimensional',
    'dimensionality',
    'dimensioning',
    'dimensions',
    'dimer',
    'dimetane',
    'dimetapp',
    'dimethylglyoxime',
    'dimetrodon',
    'diminish',
    'diminished',
    'diminishes',
    'diminishing',
    'diminuendo',
    'diminution',
    'diminutive',
    'diminutiveness',
    'dimity',
    'dimly',
    'dimmed',
    'dimmer',
    'dimness',
    'dimocarpus',
    'dimorphic',
    'dimorphism',
    'dimorphotheca',
    'dimorphous',
    'dimout',
    'dimple',
    'dimpled',
    'dimples',
    'dimwit',
    'din',
    'dinar',
    'dinars',
    'dindymene',
    'dine',
    'dined',
    'diner',
    'dinero',
    'diners',
    'dinesen',
    'dinette',
    'ding',
    'dingbat',
    'dingdong',
    'dinge',
    'dinghy',
    'dingier',
    'dinginess',
    'dinging',
    'dingle',
    'dingo',
    'dingy',
    'dining',
    'dink',
    'dinka',
    'dinkey',
    'dinky',
    'dinned',
    'dinner',
    'dinners',
    'dinnertime',
    'dinnerware',
    'dinoceras',
    'dinocerata',
    'dinocerate',
    'dinoflagellata',
    'dinoflagellate',
    'dinoflagellates',
    'dinornis',
    'dinornithidae',
    'dinornithiformes',
    'dinosaur',
    'dinosaurs',
    'dint',
    'diocesan',
    'diocese',
    'dioceses',
    'diocletian',
    'diode',
    'diodon',
    'diodontidae',
    'dioecian',
    'dioecious',
    'dioestrous',
    'dioestrual',
    'diogenes',
    'diol',
    'diomedeidae',
    'dionaea',
    'dionysia',
    'dionysian',
    'dionysius',
    'dionysus',
    'dioon',
    'diophantus',
    'diopter',
    'dioptre',
    'dior',
    'diorama',
    'diorite',
    'dioscorea',
    'dioscoreaceae',
    'diospyros',
    'diovan',
    'dioxide',
    'dioxin',
    'dip',
    'diphenhydramine',
    'diphenylbutyl',
    'diphenylhydantoin',
    'diphtheria',
    'diphthong',
    'diphthongise',
    'diphthongize',
    'diphthongized',
    'diphylla',
    'dipladenia',
    'diplegia',
    'diplococcus',
    'diplodocus',
    'diploid',
    'diploidy',
    'diploma',
    'diplomacy',
    'diplomas',
    'diplomat',
    'diplomate',
    'diplomatic',
    'diplomatical',
    'diplomatist',
    'diplomats',
    'diplopia',
    'diplopoda',
    'diplopterygium',
    'diplotaxis',
    'diplotene',
    'dipnoi',
    'dipodidae',
    'dipodomys',
    'dipogon',
    'dipolar',
    'dipole',
    'dipped',
    'dipper',
    'dippers',
    'dipping',
    'dips',
    'dipsacaceae',
    'dipsacus',
    'dipsomania',
    'dipsomaniac',
    'dipsosaurus',
    'dipstick',
    'diptera',
    'dipteran',
    'dipterocarp',
    'dipterocarpaceae',
    'dipteron',
    'dipteronia',
    'dipterous',
    'dipteryx',
    'diptych',
    'dipus',
    'dipylon',
    'dirac',
    'dirca',
    'dire',
    'direct',
    'directed',
    'directing',
    'direction',
    'directional',
    'directionality',
    'directionless',
    'directions',
    'directive',
    'directiveness',
    'directives',
    'directivity',
    'directly',
    'directness',
    'director',
    'directorate',
    'directors',
    'directorship',
    'directory',
    'directs',
    'direful',
    'dirge',
    'dirham',
    'dirhams',
    'dirigible',
    'dirk',
    'dirndl',
    'dirt',
    'dirtiness',
    'dirty',
    'dirtying',
    'dis',
    'disa',
    'disabilites',
    'disabilities',
    'disability',
    'disable',
    'disabled',
    'disablement',
    'disables',
    'disabling',
    'disabuse',
    'disabused',
    'disaccharidase',
    'disaccharide',
    'disaccharides',
    'disaccord',
    'disadvantage',
    'disadvantaged',
    'disadvantageous',
    'disadvantages',
    'disaffect',
    'disaffected',
    'disaffection',
    'disaffirmation',
    'disafforest',
    'disagree',
    'disagreeable',
    'disagreeableness',
    'disagreeably',
    'disagreed',
    'disagreeing',
    'disagreement',
    'disagreements',
    'disagrees',
    'disallow',
    'disambiguate',
    'disambiguation',
    'disambiguator',
    'disappear',
    'disappearance',
    'disappeared',
    'disappearing',
    'disappears',
    'disappoint',
    'disappointed',
    'disappointing',
    'disappointingly',
    'disappointment',
    'disappointments',
    'disappoints',
    'disapprobation',
    'disapproval',
    'disapprove',
    'disapproved',
    'disapproving',
    'disapprovingly',
    'disarm',
    'disarmament',
    'disarmed',
    'disarmer',
    'disarming',
    'disarrange',
    'disarranged',
    'disarrangement',
    'disarray',
    'disarrayed',
    'disarticulate',
    'disassemble',
    'disassembled',
    'disassembling',
    'disassembly',
    'disassociate',
    'disassociated',
    'disassociation',
    'disaster',
    'disasters',
    'disastrous',
    'disastrously',
    'disavow',
    'disavowable',
    'disavowal',
    'disavowed',
    'disband',
    'disbanded',
    'disbanding',
    'disbandment',
    'disbar',
    'disbarment',
    'disbelief',
    'disbelieve',
    'disbelieving',
    'disbud',
    'disburden',
    'disbursal',
    'disburse',
    'disbursement',
    'disbursements',
    'disburser',
    'disbursing',
    'disc',
    'discalceate',
    'discalced',
    'discant',
    'discard',
    'discarded',
    'discards',
    'discase',
    'disceptation',
    'discern',
    'discernability',
    'discernable',
    'discernible',
    'discerning',
    'discernment',
    'discerp',
    'discerped',
    'discharge',
    'discharged',
    'discharges',
    'discharging',
    'disciform',
    'discina',
    'disciple',
    'disciples',
    'discipleship',
    'disciplinal',
    'disciplinarian',
    'disciplinary',
    'discipline',
    'disciplined',
    'disciplines',
    'disclaim',
    'disclaimed',
    'disclaimer',
    'disclaiming',
    'disclike',
    'disclose',
    'disclosed',
    'discloses',
    'disclosing',
    'disclosure',
    'disco',
    'discocephali',
    'discoglossidae',
    'discography',
    'discoid',
    'discoidal',
    'discolor',
    'discoloration',
    'discolorations',
    'discolored',
    'discolorise',
    'discolorize',
    'discolors',
    'discolour',
    'discolouration',
    'discolourise',
    'discombobulate',
    'discombobulated',
    'discombobulation',
    'discomfit',
    'discomfited',
    'discomfiture',
    'discomfort',
    'discommode',
    'discompose',
    'discomposed',
    'discomposure',
    'discomycete',
    'discomycetes',
    'discomycetous',
    'disconcert',
    'disconcerted',
    'disconcerting',
    'disconcertion',
    'disconcertment',
    'disconfirming',
    'disconnect',
    'disconnected',
    'disconnectedness',
    'disconnecting',
    'disconnection',
    'disconnects',
    'disconsolate',
    'disconsolateness',
    'discontent',
    'discontented',
    'discontentedness',
    'discontentment',
    'discontinuance',
    'discontinuation',
    'discontinue',
    'discontinued',
    'discontinuing',
    'discontinuities',
    'discontinuity',
    'discontinuous',
    'discord',
    'discordance',
    'discordant',
    'discorporate',
    'discotheque',
    'discotheques',
    'discount',
    'discounted',
    'discountenance',
    'discountenanced',
    'discounter',
    'discourage',
    'discouraged',
    'discouragement',
    'discourages',
    'discouraging',
    'discourse',
    'discoursing',
    'discourteous',
    'discourtesy',
    'discover',
    'discoverable',
    'discovered',
    'discoverer',
    'discoverers',
    'discoveries',
    'discovering',
    'discovers',
    'discovery',
    'discredit',
    'discreditable',
    'discredited',
    'discrediting',
    'discredits',
    'discreet',
    'discreetly',
    'discreetness',
    'discrepancies',
    'discrepancy',
    'discrepant',
    'discrete',
    'discreteness',
    'discretion',
    'discretional',
    'discretionary',
    'discriminable',
    'discriminate',
    'discriminated',
    'discriminating',
    'discrimination',
    'discriminative',
    'discriminator',
    'discriminatory',
    'discs',
    'discursive',
    'discursiveness',
    'discus',
    'discuss',
    'discussant',
    'discussed',
    'discussing',
    'discussion',
    'discussions',
    'disdain',
    'disdained',
    'disdainful',
    'disdainfully',
    'disdainfulness',
    'disease',
    'diseased',
    'diseases',
    'disembark',
    'disembarkation',
    'disembarked',
    'disembarkment',
    'disembarrass',
    'disembarrassment',
    'disembodied',
    'disembody',
    'disembowel',
    'disembowelled',
    'disembowelment',
    'disembroil',
    'disenable',
    'disenchant',
    'disenchanted',
    'disenchanting',
    'disenchantment',
    'disencumber',
    'disenfranchise',
    'disenfranchised',
    'disenfranchisement',
    'disengage',
    'disengagement',
    'disengages',
    'disengaging',
    'disentangle',
    'disentangled',
    'disentanglement',
    'disentangler',
    'disentangles',
    'disequilibrium',
    'disestablish',
    'disestablishment',
    'disesteem',
    'disfavor',
    'disfavored',
    'disfavour',
    'disfiguration',
    'disfigure',
    'disfigured',
    'disfigurement',
    'disfigurements',
    'disfigures',
    'disfluencies',
    'disfluency',
    'disforest',
    'disforestation',
    'disfranchise',
    'disfranchised',
    'disfranchisement',
    'disfunction',
    'disgorge',
    'disgorgement',
    'disgrace',
    'disgraced',
    'disgraceful',
    'disgracefulness',
    'disgruntle',
    'disgruntled',
    'disgruntlement',
    'disguise',
    'disguised',
    'disguises',
    'disgust',
    'disgusted',
    'disgustful',
    'disgusting',
    'disgustingly',
    'disgustingness',
    'disgusts',
    'dish',
    'dishabille',
    'disharmonious',
    'disharmonize',
    'disharmony',
    'dishcloth',
    'dishearten',
    'disheartened',
    'disheartening',
    'disheartenment',
    'dished',
    'dishes',
    'dishevel',
    'disheveled',
    'dishevelled',
    'dishful',
    'dishonest',
    'dishonestly',
    'dishonesty',
    'dishonor',
    'dishonorable',
    'dishonorableness',
    'dishonored',
    'dishonour',
    'dishonourable',
    'dishonourableness',
    'dishpan',
    'dishrag',
    'dishtowel',
    'dishware',
    'dishwasher',
    'dishwashers',
    'dishwashing',
    'dishwater',
    'dishy',
    'disillusion',
    'disillusioned',
    'disillusioning',
    'disillusionment',
    'disincarnate',
    'disincentive',
    'disinclination',
    'disincline',
    'disinclined',
    'disinfect',
    'disinfectant',
    'disinfecting',
    'disinfection',
    'disinfest',
    'disinfestation',
    'disinfests',
    'disinflation',
    'disinformation',
    'disingenuous',
    'disingenuousness',
    'disinherit',
    'disinheritance',
    'disinherited',
    'disintegrable',
    'disintegrate',
    'disintegrated',
    'disintegrating',
    'disintegration',
    'disintegrations',
    'disintegrative',
    'disinter',
    'disinterest',
    'disinterested',
    'disinterestedness',
    'disinterment',
    'disinvest',
    'disinvested',
    'disinvestment',
    'disinvolve',
    'disjoin',
    'disjoined',
    'disjoint',
    'disjointed',
    'disjointedness',
    'disjoints',
    'disjunct',
    'disjunction',
    'disjunctive',
    'disjuncture',
    'disk',
    'diskette',
    'disklike',
    'disks',
    'dislikable',
    'dislike',
    'disliked',
    'dislikes',
    'disliking',
    'dislocate',
    'dislocated',
    'dislocation',
    'dislocations',
    'dislodge',
    'dislodged',
    'dislodgement',
    'dislodging',
    'dislodgment',
    'dislogistic',
    'disloyal',
    'disloyalty',
    'dismal',
    'dismantle',
    'dismantled',
    'dismantlement',
    'dismantles',
    'dismantling',
    'dismay',
    'dismayed',
    'dismaying',
    'dismember',
    'dismembered',
    'dismemberment',
    'dismiss',
    'dismissal',
    'dismissed',
    'dismisses',
    'dismissible',
    'dismission',
    'dismissive',
    'dismount',
    'dismounting',
    'dismutase',
    'disney',
    'disneyland',
    'disobedience',
    'disobedient',
    'disobey',
    'disobeyed',
    'disoblige',
    'disobliging',
    'disorder',
    'disordered',
    'disorderliness',
    'disorderly',
    'disorders',
    'disorganisation',
    'disorganise',
    'disorganised',
    'disorganization',
    'disorganize',
    'disorganized',
    'disorient',
    'disorientate',
    'disorientation',
    'disoriented',
    'disorienting',
    'disown',
    'disowned',
    'disowning',
    'disownment',
    'disparage',
    'disparaged',
    'disparagement',
    'disparager',
    'disparages',
    'disparaging',
    'disparagingly',
    'disparate',
    'disparateness',
    'disparity',
    'dispassion',
    'dispassionate',
    'dispassionateness',
    'dispatch',
    'dispatched',
    'dispatcher',
    'dispatches',
    'dispel',
    'dispelled',
    'dispelling',
    'dispensability',
    'dispensable',
    'dispensableness',
    'dispensary',
    'dispensation',
    'dispense',
    'dispensed',
    'dispenser',
    'dispenses',
    'dispensing',
    'dispersal',
    'disperse',
    'dispersed',
    'disperses',
    'dispersing',
    'dispersion',
    'dispersive',
    'dispirit',
    'dispirited',
    'dispiritedness',
    'dispiriting',
    'displace',
    'displaced',
    'displacement',
    'displacements',
    'displaces',
    'display',
    'displayed',
    'displaying',
    'displays',
    'displease',
    'displeased',
    'displeasing',
    'displeasure',
    'displume',
    'disport',
    'disposable',
    'disposal',
    'dispose',
    'disposed',
    'disposes',
    'disposing',
    'disposition',
    'dispositions',
    'dispossed',
    'dispossess',
    'dispossessed',
    'dispossessing',
    'dispossession',
    'dispraise',
    'dispread',
    'disproof',
    'disproportion',
    'disproportional',
    'disproportionate',
    'disproportionately',
    'disprove',
    'disproved',
    'disprover',
    'disproves',
    'disproving',
    'disputable',
    'disputant',
    'disputation',
    'disputatious',
    'disputative',
    'dispute',
    'disputed',
    'disputes',
    'disputing',
    'disqualification',
    'disqualified',
    'disqualifies',
    'disqualify',
    'disqualifying',
    'disquiet',
    'disquieted',
    'disquieting',
    'disquietude',
    'disquisition',
    'disraeli',
    'disregard',
    'disregarded',
    'disregarding',
    'disregards',
    'disrepair',
    'disreputability',
    'disreputable',
    'disreputableness',
    'disrepute',
    'disrespect',
    'disrespectful',
    'disrespectfully',
    'disrobe',
    'disrupt',
    'disrupted',
    'disrupting',
    'disruption',
    'disruptive',
    'disrupts',
    'diss',
    'dissatisfaction',
    'dissatisfactory',
    'dissatisfied',
    'dissatisfy',
    'dissect',
    'dissected',
    'dissection',
    'dissed',
    'dissemble',
    'dissembler',
    'dissembling',
    'disseminate',
    'disseminated',
    'disseminates',
    'disseminating',
    'dissemination',
    'disseminative',
    'disseminator',
    'dissension',
    'dissensions',
    'dissent',
    'dissenter',
    'dissenters',
    'dissentient',
    'dissenting',
    'dissentious',
    'dissents',
    'dissertate',
    'dissertated',
    'dissertation',
    'disservice',
    'dissever',
    'dissidence',
    'dissident',
    'dissidents',
    'dissilience',
    'dissilient',
    'dissimilar',
    'dissimilarity',
    'dissimilate',
    'dissimilated',
    'dissimilation',
    'dissimilitude',
    'dissimulate',
    'dissimulation',
    'dissimulative',
    'dissimulator',
    'dissipate',
    'dissipated',
    'dissipates',
    'dissipation',
    'dissociable',
    'dissociate',
    'dissociated',
    'dissociates',
    'dissociation',
    'dissociative',
    'dissolubility',
    'dissoluble',
    'dissolute',
    'dissoluteness',
    'dissolution',
    'dissolvable',
    'dissolve',
    'dissolved',
    'dissolvent',
    'dissolver',
    'dissolves',
    'dissolving',
    'dissonance',
    'dissonant',
    'dissonate',
    'dissonated',
    'dissuade',
    'dissuades',
    'dissuasion',
    'dissuasive',
    'dissyllable',
    'dissymmetry',
    'distaff',
    'distal',
    'distance',
    'distances',
    'distant',
    'distantly',
    'distaste',
    'distasteful',
    'distastefulness',
    'distemper',
    'distend',
    'distended',
    'distensible',
    'distension',
    'distention',
    'distich',
    'distichum',
    'distil',
    'distill',
    'distillate',
    'distillates',
    'distillation',
    'distilled',
    'distiller',
    'distillery',
    'distilling',
    'distillment',
    'distills',
    'distinct',
    'distinction',
    'distinctions',
    'distinctive',
    'distinctiveness',
    'distinctly',
    'distinctness',
    'distinguish',
    'distinguishable',
    'distinguished',
    'distinguishes',
    'distinguishing',
    'distomatosis',
    'distort',
    'distortable',
    'distorted',
    'distorting',
    'distortion',
    'distortionist',
    'distortions',
    'distorts',
    'distract',
    'distracted',
    'distracting',
    'distraction',
    'distracts',
    'distrain',
    'distraint',
    'distrait',
    'distraught',
    'distress',
    'distressed',
    'distressful',
    'distressfulness',
    'distressing',
    'distressingness',
    'distributary',
    'distribute',
    'distributed',
    'distributer',
    'distributes',
    'distributing',
    'distribution',
    'distributional',
    'distributive',
    'distributor',
    'distributors',
    'district',
    'districts',
    'distruction',
    'distrust',
    'distrusted',
    'distrustful',
    'distrustfulness',
    'distrusts',
    'disturb',
    'disturbance',
    'disturbances',
    'disturbed',
    'disturber',
    'disturbing',
    'disturbingly',
    'disturbs',
    'disulfiram',
    'disunify',
    'disunion',
    'disunite',
    'disunited',
    'disunity',
    'disuse',
    'disused',
    'disyllabic',
    'disyllable',
    'dit',
    'dita',
    'ditch',
    'ditches',
    'ditchmoss',
    'dither',
    'dithering',
    'dithyramb',
    'dithyrambic',
    'dittany',
    'ditto',
    'dittoed',
    'ditty',
    'diuresis',
    'diuretic',
    'diuretics',
    'diuril',
    'diurnal',
    'diva',
    'divagate',
    'divagation',
    'divalent',
    'divan',
    'divaricate',
    'divaricates',
    'divarication',
    'dive',
    'dived',
    'diver',
    'diverge',
    'divergence',
    'divergency',
    'divergent',
    'diverges',
    'diverging',
    'divers',
    'diverse',
    'diverseness',
    'diversification',
    'diversified',
    'diversify',
    'diversion',
    'diversionary',
    'diversionist',
    'diversity',
    'divert',
    'diverted',
    'diverticula',
    'diverticulitis',
    'diverticulosis',
    'diverticulum',
    'divertimento',
    'diverting',
    'diverts',
    'dives',
    'divest',
    'divested',
    'divestiture',
    'dividable',
    'divide',
    'divided',
    'dividend',
    'dividends',
    'divider',
    'divides',
    'dividing',
    'divination',
    'divinatory',
    'divine',
    'divinely',
    'diviner',
    'divines',
    'diving',
    'divining',
    'divinities',
    'divinity',
    'divinorum',
    'divisibility',
    'divisible',
    'division',
    'divisional',
    'divisions',
    'divisive',
    'divisor',
    'divorce',
    'divorced',
    'divorcee',
    'divorcement',
    'divot',
    'divulge',
    'divulgement',
    'divulgence',
    'divulging',
    'divvy',
    'diwan',
    'dix',
    'dixie',
    'dixiecrats',
    'dixieland',
    'dizen',
    'dizygotic',
    'dizygous',
    'dizzied',
    'dizziness',
    'dizzy',
    'dizzying',
    'dj',
    'djakarta',
    'djanet',
    'djibouti',
    'djiboutian',
    'djinn',
    'djinni',
    'djinny',
    'dkg',
    'dkl',
    'dkm',
    'dl',
    'dle',
    'dm',
    'dmd',
    'dmus',
    'dmz',
    'dna',
    'dneprodzerzhinsk',
    'dnieper',
    'dnipropetrovsk',
    'do',
    'doable',
    'dobbin',
    'doberman',
    'dobra',
    'dobrich',
    'dobson',
    'dobsonfly',
    'dobsons',
    'dobzhansky',
    'doc',
    'docent',
    'docetism',
    'docile',
    'docility',
    'dock',
    'dockage',
    'docker',
    'docket',
    'docketed',
    'dockhand',
    'docking',
    'dockside',
    'dockworker',
    'dockyard',
    'doctor',
    'doctoral',
    'doctorate',
    'doctorfish',
    'doctorfishes',
    'doctorial',
    'doctorow',
    'doctors',
    'doctorspeak',
    'doctrinaire',
    'doctrinal',
    'doctrine',
    'doctrines',
    'docudrama',
    'document',
    'documental',
    'documentary',
    'documentation',
    'documented',
    'documenting',
    'documents',
    'dod',
    'dodder',
    'dodderer',
    'doddering',
    'dodders',
    'doddery',
    'doddle',
    'dodecagon',
    'dodecahedron',
    'dodecanese',
    'dodge',
    'dodged',
    'dodgem',
    'dodger',
    'dodging',
    'dodgson',
    'dodgy',
    'dodo',
    'dodoma',
    'dodonaea',
    'dodos',
    'doe',
    'doei',
    'doer',
    'does',
    'doeskin',
    'doff',
    'doffed',
    'dog',
    'dogbane',
    'dogcart',
    'doge',
    'dogfight',
    'dogfighter',
    'dogfights',
    'dogfish',
    'dogfishes',
    'dogged',
    'doggedly',
    'doggedness',
    'doggerel',
    'doggie',
    'dogging',
    'doggy',
    'doghouse',
    'dogie',
    'dogleg',
    'doglike',
    'dogma',
    'dogmatic',
    'dogmatical',
    'dogmatically',
    'dogmatise',
    'dogmatism',
    'dogmatist',
    'dogmatize',
    'dogs',
    'dogsbody',
    'dogshit',
    'dogsled',
    'dogtooth',
    'dogtrot',
    'dogwatch',
    'dogwood',
    'dogwoods',
    'dogy',
    'doh',
    'doha',
    'doi',
    'doily',
    'doing',
    'doings',
    'doj',
    'dojc',
    'dol',
    'dolabrate',
    'dolabriform',
    'dolby',
    'doldrums',
    'dole',
    'doleful',
    'dolefulness',
    'dolichocephalic',
    'dolichocephalism',
    'dolichocephaly',
    'dolichocranial',
    'dolichocranic',
    'dolichonyx',
    'dolichos',
    'dolichotis',
    'doliolidae',
    'doliolum',
    'doll',
    'dollar',
    'dollarfish',
    'dollars',
    'dolled',
    'dollhouse',
    'dollop',
    'dolls',
    'dolly',
    'dolman',
    'dolmas',
    'dolmen',
    'dolobid',
    'dolomite',
    'dolomitic',
    'dolor',
    'dolorous',
    'dolour',
    'dolourous',
    'dolphin',
    'dolphinfish',
    'dolphins',
    'dolt',
    'doltish',
    'domain',
    'domatium',
    'dombeya',
    'dome',
    'domed',
    'domes',
    'domestic',
    'domestica',
    'domesticate',
    'domesticated',
    'domestication',
    'domesticise',
    'domesticity',
    'domesticize',
    'domicile',
    'domiciliary',
    'domiciliate',
    'domiciliation',
    'dominance',
    'dominant',
    'dominate',
    'dominated',
    'dominates',
    'dominating',
    'domination',
    'dominatrix',
    'domine',
    'dominee',
    'domineer',
    'domineering',
    'domineeringness',
    'domingo',
    'dominic',
    'dominica',
    'dominical',
    'dominican',
    'dominicans',
    'dominick',
    'dominicus',
    'dominie',
    'dominion',
    'dominions',
    'dominique',
    'domino',
    'dominoes',
    'dominos',
    'dominus',
    'domitian',
    'don',
    'dona',
    'donald',
    'donar',
    'donate',
    'donated',
    'donatello',
    'donates',
    'donation',
    'donations',
    'donatism',
    'donatist',
    'donatus',
    'donbas',
    'donbass',
    'done',
    'donee',
    'donets',
    'donetsk',
    'donetske',
    'dong',
    'dongle',
    'donizetti',
    'donjon',
    'donkey',
    'donkeys',
    'donkeywork',
    'donkin',
    'donna',
    'donne',
    'donnean',
    'donned',
    'donnian',
    'donnish',
    'donor',
    'donut',
    'doob',
    'doodad',
    'doodia',
    'doodle',
    'doodlebug',
    'doofus',
    'doohickey',
    'doojigger',
    'doolittle',
    'doom',
    'doomed',
    'doomsday',
    'door',
    'doorbell',
    'doorcase',
    'doorframe',
    'doorhandle',
    'doorjamb',
    'doorkeeper',
    'doorknob',
    'doorknocker',
    'doorlock',
    'doorman',
    'doormat',
    'doornail',
    'doorplate',
    'doorpost',
    'doors',
    'doorsill',
    'doorstep',
    'doorstop',
    'doorstopper',
    'doorway',
    'doorways',
    'dooryard',
    'dopa',
    'dopamine',
    'dopastat',
    'dope',
    'doped',
    'dopey',
    'doppelganger',
    'doppelzentner',
    'doppler',
    'dopy',
    'dorado',
    'dorbeetle',
    'doren',
    'dorian',
    'dorians',
    'doric',
    'doriden',
    'dories',
    'doris',
    'dork',
    'dorking',
    'dorm',
    'dormancy',
    'dormant',
    'dormer',
    'dormice',
    'dormie',
    'dormition',
    'dormitories',
    'dormitory',
    'dormouse',
    'dormy',
    'doronicum',
    'dorotheanthus',
    'dorothy',
    'dorsal',
    'dorsally',
    'dorsiflexion',
    'dorsoventral',
    'dorsoventrally',
    'dorsum',
    'dortmund',
    'dory',
    'dorylinae',
    'doryopteris',
    'dos',
    'dosage',
    'dose',
    'dosed',
    'dosemeter',
    'doses',
    'dosimeter',
    'dosimetry',
    'doss',
    'dossal',
    'dossel',
    'dosser',
    'dosshouse',
    'dossier',
    'dostoevski',
    'dostoevskian',
    'dostoevsky',
    'dostoyevskian',
    'dostoyevsky',
    'dot',
    'dotage',
    'dotard',
    'dote',
    'dotes',
    'doth',
    'doting',
    'dotrel',
    'dots',
    'dotted',
    'dotterel',
    'dottle',
    'dotty',
    'douala',
    'double',
    'doubled',
    'doubleheader',
    'doubler',
    'doubles',
    'doublespeak',
    'doublet',
    'doublethink',
    'doubleton',
    'doubletree',
    'doubling',
    'doubloon',
    'doubly',
    'doubt',
    'doubted',
    'doubter',
    'doubtful',
    'doubtfulness',
    'doubting',
    'doubts',
    'douche',
    'dough',
    'doughboy',
    'doughnut',
    'doughnuts',
    'doughs',
    'doughy',
    'douglas',
    'douglass',
    'doula',
    'dour',
    'doura',
    'dourah',
    'douroucouli',
    'douroucoulis',
    'douse',
    'dousing',
    'dove',
    'dovecote',
    'dovekie',
    'dover',
    'doves',
    'dovetail',
    'dovetailing',
    'dovish',
    'dovishness',
    'dovyalis',
    'dow',
    'dowager',
    'dowdiness',
    'dowding',
    'dowdy',
    'dowel',
    'doweling',
    'dowels',
    'dower',
    'dowered',
    'dowerless',
    'dowery',
    'dowitcher',
    'dowitchers',
    'dowland',
    'down',
    'downbeat',
    'downbound',
    'downcast',
    'downdraft',
    'downdrafts',
    'downed',
    'downer',
    'downfall',
    'downfield',
    'downgrade',
    'downhearted',
    'downheartedness',
    'downhill',
    'downiness',
    'downing',
    'downlike',
    'download',
    'downloaded',
    'downmarket',
    'downplay',
    'downpour',
    'downright',
    'downrightness',
    'downs',
    'downscale',
    'downshift',
    'downside',
    'downsize',
    'downsized',
    'downsizing',
    'downslope',
    'downspin',
    'downstage',
    'downstair',
    'downstairs',
    'downstream',
    'downstroke',
    'downstrokes',
    'downswing',
    'downtick',
    'downtime',
    'downtown',
    'downtrodden',
    'downturn',
    'downward',
    'downwards',
    'downwind',
    'downy',
    'dowry',
    'dowse',
    'dowser',
    'dowsing',
    'doxazosin',
    'doxepin',
    'doxology',
    'doxorubicin',
    'doxy',
    'doxycycline',
    'doyen',
    'doyenne',
    'doyle',
    'doyley',
    'doyly',
    'doze',
    'dozed',
    'dozen',
    'dozens',
    'dozer',
    'dozy',
    'dp',
    'dph',
    'dphil',
    'dprk',
    'drab',
    'draba',
    'drabness',
    'dracaena',
    'dracaenaceae',
    'dracenaceae',
    'drachm',
    'drachma',
    'draco',
    'dracocephalum',
    'draconian',
    'dracontium',
    'dracula',
    'dracunculiasis',
    'dracunculidae',
    'dracunculus',
    'draft',
    'drafted',
    'draftee',
    'drafter',
    'drafting',
    'draftsman',
    'draftsmanship',
    'draftsmen',
    'draftsperson',
    'drafty',
    'drag',
    'dragee',
    'dragged',
    'dragger',
    'dragging',
    'draggingly',
    'draggle',
    'draggled',
    'dragnet',
    'dragoman',
    'dragomans',
    'dragon',
    'dragonet',
    'dragonets',
    'dragonflies',
    'dragonfly',
    'dragonhead',
    'dragonheads',
    'dragons',
    'dragoon',
    'drags',
    'dragunov',
    'drain',
    'drainage',
    'drainboard',
    'drained',
    'draining',
    'drainpipe',
    'drainplug',
    'drains',
    'drake',
    'dram',
    'drama',
    'dramamine',
    'dramas',
    'dramatic',
    'dramatically',
    'dramatics',
    'dramatisation',
    'dramatise',
    'dramatist',
    'dramatists',
    'dramatization',
    'dramatize',
    'dramaturgic',
    'dramaturgical',
    'dramaturgy',
    'drambuie',
    'drams',
    'drank',
    'drape',
    'draped',
    'draper',
    'draperies',
    'drapery',
    'drastic',
    'drastically',
    'draught',
    'draughts',
    'draughtsman',
    'draughty',
    'dravidian',
    'dravidic',
    'draw',
    'drawback',
    'drawbacks',
    'drawbar',
    'drawbridge',
    'drawee',
    'drawer',
    'drawers',
    'drawing',
    'drawings',
    'drawknife',
    'drawl',
    'drawler',
    'drawn',
    'drawnwork',
    'draws',
    'drawshave',
    'drawstring',
    'dray',
    'drayhorse',
    'dread',
    'dreaded',
    'dreadful',
    'dreadfully',
    'dreadfulness',
    'dreadlock',
    'dreadlocks',
    'dreadnaught',
    'dreadnought',
    'dream',
    'dreamed',
    'dreamer',
    'dreaminess',
    'dreaming',
    'dreamland',
    'dreamless',
    'dreamlike',
    'dreams',
    'dreamt',
    'dreamworld',
    'dreamy',
    'drear',
    'dreariness',
    'dreary',
    'dreck',
    'dredge',
    'dredger',
    'dredging',
    'dreg',
    'dregs',
    'dreiser',
    'dreissena',
    'drench',
    'drenched',
    'drenching',
    'drepanididae',
    'drepanis',
    'dresden',
    'dress',
    'dressage',
    'dressed',
    'dresser',
    'dresses',
    'dressing',
    'dressings',
    'dressmaker',
    'dressmaking',
    'dressy',
    'drew',
    'drey',
    'dreyfus',
    'drib',
    'dribble',
    'dribbler',
    'dribbling',
    'driblet',
    'dried',
    'drier',
    'dries',
    'driest',
    'drift',
    'driftage',
    'drifted',
    'drifter',
    'driftfish',
    'drifting',
    'drifts',
    'driftwood',
    'drill',
    'drilled',
    'drilling',
    'drills',
    'drimys',
    'drink',
    'drinkable',
    'drinker',
    'drinking',
    'drinks',
    'drip',
    'dripless',
    'drippage',
    'dripped',
    'drippiness',
    'dripping',
    'drippings',
    'drippy',
    'drips',
    'dripstone',
    'drive',
    'drivel',
    'driveller',
    'driven',
    'driver',
    'drivers',
    'drives',
    'driveshaft',
    'driveway',
    'drivewaylittered',
    'driving',
    'drixoral',
    'drizzing',
    'drizzle',
    'drizzles',
    'drizzling',
    'drizzly',
    'drms',
    'drogheda',
    'drogue',
    'droll',
    'drollery',
    'dromaeosaur',
    'dromaeosauridae',
    'dromaeosaurs',
    'dromaius',
    'drome',
    'dromedary',
    'dronabinol',
    'drone',
    'droning',
    'drool',
    'drooler',
    'droop',
    'drooping',
    'droopy',
    'drop',
    'dropforge',
    'dropkick',
    'dropkicker',
    'droplet',
    'droplets',
    'dropline',
    'dropout',
    'dropped',
    'dropper',
    'dropping',
    'droppings',
    'drops',
    'dropseed',
    'dropsical',
    'dropsy',
    'dropworts',
    'drosera',
    'droseraceae',
    'droshky',
    'drosky',
    'drosophila',
    'drosophilidae',
    'drosophyllum',
    'dross',
    'drought',
    'drouth',
    'drove',
    'drover',
    'drown',
    'drowned',
    'drowning',
    'drowse',
    'drowsiness',
    'drowsing',
    'drowsy',
    'drub',
    'drubbing',
    'drudge',
    'drudgery',
    'drudging',
    'drug',
    'drugged',
    'drugget',
    'drugging',
    'druggist',
    'drugless',
    'drugs',
    'drugstore',
    'druid',
    'druidism',
    'druids',
    'drum',
    'drumbeat',
    'drumbeater',
    'drumfire',
    'drumfish',
    'drumhead',
    'drumlin',
    'drummed',
    'drummer',
    'drumming',
    'drums',
    'drumstick',
    'drumsticks',
    'drunk',
    'drunkard',
    'drunken',
    'drunkenness',
    'drunks',
    'drupaceous',
    'drupe',
    'drupelet',
    'drupes',
    'druse',
    'drusen',
    'druthers',
    'druze',
    'dry',
    'dryad',
    'dryadella',
    'dryas',
    'dryden',
    'drydock',
    'dryer',
    'drygoods',
    'drying',
    'drymarchon',
    'drymoglossum',
    'drynaria',
    'dryness',
    'dryopithecine',
    'dryopithecus',
    'dryopteridaceae',
    'dryopteris',
    'drypis',
    'drywall',
    'ds',
    'dscdna',
    'dsl',
    'dtic',
    'dts',
    'du',
    'duad',
    'dual',
    'dualism',
    'dualist',
    'dualistic',
    'duality',
    'dub',
    'dubai',
    'dubbin',
    'dubbing',
    'dubiety',
    'dubious',
    'dubiousness',
    'dubitable',
    'dublin',
    'dubliner',
    'dubnium',
    'dubonnet',
    'dubrovnik',
    'dubuque',
    'dubya',
    'dubyuh',
    'ducal',
    'ducat',
    'duce',
    'duchamp',
    'duchess',
    'duchy',
    'duck',
    'duckbill',
    'duckboard',
    'ducked',
    'ducking',
    'duckling',
    'ducklings',
    'duckpin',
    'duckpins',
    'ducks',
    'duckweed',
    'ducky',
    'duct',
    'ductile',
    'ductileness',
    'ductility',
    'ductless',
    'ducts',
    'ductule',
    'ductulus',
    'ductus',
    'dud',
    'dude',
    'dudeen',
    'dudgeon',
    'duds',
    'due',
    'duel',
    'dueled',
    'dueler',
    'duelist',
    'dueller',
    'duellist',
    'duels',
    'duenna',
    'dues',
    'duet',
    'duette',
    'duff',
    'duffel',
    'duffer',
    'duffle',
    'dufy',
    'dug',
    'dugong',
    'dugongidae',
    'dugongs',
    'dugout',
    'dukas',
    'duke',
    'dukedom',
    'dukes',
    'dulcet',
    'dulciana',
    'dulcify',
    'dulcimer',
    'dulcinea',
    'dulcorate',
    'dull',
    'dullard',
    'dulled',
    'duller',
    'dulles',
    'dullness',
    'dulls',
    'dulse',
    'duluth',
    'duly',
    'duma',
    'dumas',
    'dumb',
    'dumbass',
    'dumbbell',
    'dumbfound',
    'dumbfounded',
    'dumbfounding',
    'dumbness',
    'dumbstricken',
    'dumbstruck',
    'dumbwaiter',
    'dumdum',
    'dumetella',
    'dumfounded',
    'dumfounding',
    'dummy',
    'dump',
    'dumpcart',
    'dumped',
    'dumper',
    'dumpiness',
    'dumping',
    'dumpling',
    'dumplings',
    'dumps',
    'dumpsite',
    'dumpster',
    'dumpy',
    'dumuzi',
    'dun',
    'duncan',
    'dunce',
    'duncical',
    'duncish',
    'dunderhead',
    'dune',
    'dunes',
    'dung',
    'dungaree',
    'dungeon',
    'dunghill',
    'dunk',
    'dunkard',
    'dunked',
    'dunker',
    'dunkerque',
    'dunkers',
    'dunkirk',
    'dunlin',
    'dunned',
    'dunnock',
    'duo',
    'duodecimal',
    'duodenal',
    'duodenum',
    'duologue',
    'duomo',
    'dupe',
    'duped',
    'dupery',
    'duple',
    'duplex',
    'duplicability',
    'duplicable',
    'duplicatable',
    'duplicate',
    'duplicated',
    'duplicates',
    'duplicating',
    'duplication',
    'duplicator',
    'duplicidentata',
    'duplicitous',
    'duplicity',
    'dura',
    'durability',
    'durable',
    'durables',
    'durabolin',
    'dural',
    'duralumin',
    'duramen',
    'durance',
    'durango',
    'durant',
    'durante',
    'duration',
    'durations',
    'durative',
    'durazzo',
    'durban',
    'durbar',
    'durer',
    'duress',
    'durga',
    'durham',
    'durian',
    'during',
    'durio',
    'durion',
    'durkheim',
    'durmast',
    'durra',
    'durrell',
    'durres',
    'durum',
    'dusanbe',
    'duse',
    'dushanbe',
    'dusicyon',
    'dusk',
    'duskiness',
    'dusky',
    'dusseldorf',
    'dust',
    'dustbin',
    'dustcart',
    'dustcloth',
    'dusted',
    'duster',
    'dustin',
    'dustiness',
    'dusting',
    'dustlike',
    'dustman',
    'dustmop',
    'dustpan',
    'dustpanful',
    'dustrag',
    'dustup',
    'dusty',
    'dutch',
    'dutchman',
    'duteous',
    'dutiable',
    'duties',
    'dutiful',
    'dutifully',
    'dutifulness',
    'duty',
    'duvalier',
    'duvet',
    'dvd',
    'dvorak',
    'dwarf',
    'dwarfed',
    'dwarfish',
    'dwarfishness',
    'dwarfism',
    'dwarfs',
    'dweeb',
    'dwell',
    'dweller',
    'dwelling',
    'dwellings',
    'dwells',
    'dwelt',
    'dwight',
    'dwindle',
    'dwindled',
    'dwindling',
    'dy',
    'dyad',
    'dyadic',
    'dyarchy',
    'dyaus',
    'dybbuk',
    'dye',
    'dyed',
    'dyeing',
    'dyer',
    'dyes',
    'dyestuff',
    'dyeweed',
    'dyewood',
    'dyewoods',
    'dying',
    'dyirbal',
    'dyke',
    'dylan',
    'dynamic',
    'dynamical',
    'dynamically',
    'dynamics',
    'dynamise',
    'dynamism',
    'dynamite',
    'dynamiter',
    'dynamitist',
    'dynamize',
    'dynamized',
    'dynamo',
    'dynamometer',
    'dynapen',
    'dynast',
    'dynastic',
    'dynasties',
    'dynasty',
    'dyne',
    'dynes',
    'dysaphia',
    'dysarthria',
    'dyscalculia',
    'dyschezia',
    'dyscrasia',
    'dysdercus',
    'dysentery',
    'dysfunction',
    'dysfunctional',
    'dysfunctions',
    'dysgenesis',
    'dysgenic',
    'dysgenics',
    'dysgraphia',
    'dyskinesia',
    'dyslectic',
    'dyslexia',
    'dyslexic',
    'dyslogia',
    'dyslogistic',
    'dysmenorrhea',
    'dysomia',
    'dysosmia',
    'dyspepsia',
    'dyspeptic',
    'dysphagia',
    'dysphasia',
    'dysphemism',
    'dysphemistic',
    'dysphonia',
    'dysphoria',
    'dysphoric',
    'dysplasia',
    'dysplastic',
    'dyspnea',
    'dyspneal',
    'dyspneic',
    'dyspnoea',
    'dyspnoeal',
    'dyspnoeic',
    'dysprosium',
    'dyssynergia',
    'dysthymia',
    'dysthymic',
    'dystopia',
    'dystopian',
    'dystrophy',
    'dysuria',
    'dytiscidae',
    'dyushambe',
    'dziggetai']
